/*
 * Java Template Project
 * 
 * Copyright (C) 2006 Satoshi Nagashiba, All Rights Reserved.
 */
package org.jtp.web.action.sample;

import java.util.Iterator;
import java.util.List;
import java.util.Set;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.validator.DynaValidatorActionForm;
import org.jtp.SampleException;
import org.jtp.common.util.PropertyUtilsWrapper;
import org.jtp.entity.test.TestTable;
import org.jtp.entity.test.TestTableDetail;
import org.jtp.logic.test.TestTableService;
import org.jtp.web.action.BaseAction;

/**
 * 更新画面のアクションクラスです。
 * 
 * @struts.action
 *  name="sample/UpdateForm"
 *  path="/sample/update"
 *  scope="request"
 *  validate="true"
 *  input="/sample/update.tiles"
 *  parameter="event"
 * @struts.action-forward
 *  name="success"
 *  path="/sample/search.tiles"
 * @struts.action-forward
 *  name="cancel"
 *  path="/sample/search.tiles"
 *
 * @author <a href="mailto:sato-vista@jade.plala.or.jp">Satoshi Nagashiba</a>
 */
public class UpdateAction extends BaseAction {

    /** テストテーブル情報サービス */
    private TestTableService testTableService;

    
    /**
     * テストテーブル情報サービスを設定します。
     * @param testTableService テストテーブル情報サービス
     */
	public void setTestTableService(TestTableService testTableService) {
		this.testTableService = testTableService;
	}

	/**
	 * 更新アクションを処理します。
     * @param mapping  このインスタンスを選択するために使用したActionMapping
     * @param form     存在するならば、このリクエストのためのActionForm Bean
     * @param request  処理しているHTTPリクエスト
     * @param response 処理しているHTTPレスポンス
     * @return 指定された非HTTPリクエストを処理して、 対応する非HTTPレスポンスを生成します
     * （またはレスポンスを生成する他のWebコンポーネントにリクエストをフォワードします）。
     * @throws SampleException システム例外
	 */
	public ActionForward success(ActionMapping mapping, ActionForm form,
            HttpServletRequest request, HttpServletResponse response) throws Exception {
		
		Integer id = new Integer(request.getParameter("id"));

		TestTable entity = null;

		List list = (List) request.getSession().getAttribute("list");
		for (Iterator it = list.iterator(); it.hasNext();) {
			entity = (TestTable) it.next();
			if (entity.getId().intValue() == id.intValue()) {
				PropertyUtilsWrapper.copyProperties(((DynaValidatorActionForm) form).getMap(), entity);

		     	Set set = entity.getTestTableDetails();
		     	for (Iterator ite = set.iterator(); ite.hasNext();) {
		     		TestTableDetail detail = (TestTableDetail) ite.next();
		    		PropertyUtilsWrapper.copyProperties(((DynaValidatorActionForm) form).getMap(), detail);
		     	}
				break;
			}
		}
		
		testTableService.update(entity);
		
		request.getSession(false).setAttribute("list", testTableService.find(new TestTable()));
		
		return mapping.findForward(request.getParameter(FORWARD_EVENT));
	}
}
